//
// This code is part of https://developer.mescius.com/document-solutions/dot-net-imaging-api/demos.
// Copyright (c) MESCIUS inc. All rights reserved.
//
using System;
using System.IO;
using System.Drawing;
using System.Collections.Generic;
using System.Linq;
using System.Numerics;
using GrapeCity.Documents.Drawing;
using GrapeCity.Documents.Text;
using GrapeCity.Documents.Imaging;
using GrapeCity.Documents.Svg;
using GCTEXT = GrapeCity.Documents.Text;
using GCDRAW = GrapeCity.Documents.Drawing;
using DsImagingWeb.Demos.Common;

namespace DsImagingWeb.Demos
{
    // This sample shows how to measure and render the actual SVG content
    // that sometimes is offset within the SVG viewport.
    // In the left part of the page, we render such an SVG as it is supposed
    // to be laid out within its viewport. A gray border is drawn around the viewport,
    // and a magenta border is around the SVG content.
    // In the right part of the page we locate just the content at a specific point
    // in the final image, and draw a purple border around it.
    //
    // This short sample shows how to measure and render an SVG image.
    // The SVG art used in this sample is from https://freesvg.org/.
    public class RenderSvgContent
    {
        public GcBitmap GenerateImage(Size pixelSize, float dpi, bool opaque, string[] sampleParams = null)
        {
            // Load the SVG:
            var svgPath = Path.Combine("Resources", "SvgMisc", "Smiling-Girl-offset.svg");
            using var svg = GcSvgDocument.FromFile(svgPath);

            var bmp = new GcBitmap(pixelSize.Width, pixelSize.Height, opaque, dpi, dpi);
            using var g = bmp.CreateGraphics(Color.White);
            var pt0 = new PointF(g.Resolution, g.Resolution);

            // Render the SVG content as specified by the SVG layout within viewport:
            var rcViewport = new RectangleF(pt0, svg.GetIntrinsicSize(SvgLengthUnits.Pixels));
            // Measure the content size/location relative to 'pt':
            var rcContent0 = g.MeasureSvg(svg, pt0);
            // Draw the SVG and viewport and content bounds:
            g.DrawSvg(svg, pt0);
            g.DrawRectangle(rcViewport, Color.DarkGray);
            g.DrawRectangle(rcContent0, Color.Magenta);

            // In the left part of the bitmap, render just the SVG content
            // aligning its top left corner to a specific point on the bitmap
            // (center of page horizontally, 1" from the top):
            var pt1 = new PointF(pixelSize.Width / 2, g.Resolution);
            // An alternative to GcGraphics.MeasureSvg() is GcSvgDocument.Measure(),
            // here we use it for illustration but these methods are calculations heavy,
            // so in a real app we would re-use the results from GcGraphics.MeasureSvg() above:
            var rcContent1 = svg.Measure(PointF.Empty, dpi);
            g.DrawSvg(svg, new PointF(pt1.X - rcContent1.X, pt1.Y - rcContent1.Y));
            // Add a border:
            g.DrawRectangle(new RectangleF(pt1, rcContent1.Size), Color.Purple);

            // Done:
            return bmp;
        }
    }
}
